## common.make -- defines many values used in our makefiles, etc.

# Which kind of chip
PIC=16f628a

## picprog options -- see http://hyvatti.iki.fi/~jaakko/pic/picprog.html
# The serial port your JDM programmer is attached to
PIC_PORT=/dev/ttyS1
# Tells picprog which serial port to program what kind of device on
PICPROG_OPTS=--pic-serial-port=$(PIC_PORT) --device=pic$(PIC)
# Needed to reliably program PICs on my computer.  Your mileage may vary.
PICPROG_OPTS+=--rdtsc

## SDCC paths.  Alter to fit your system.
SDCC_DIR=/usr/share/sdcc
SDCC_LIB=$(SDCC_DIR)/lib/pic

## SDCC compile flags
# Defines include paths, what kind of chip, and a flag some SDCC includes need
CFLAGS=-I./include/ -mpic14 -p$(PIC) -D__$(PIC)
# Defines the default value for the CONFIG word.  Some things in the 
# files depend on this -- _INTOSC_OSC_NOCLKOUT frees up the clock pins 
# as I/O pins A6 and A7, for instance.
CFLAGS+=-DCONFIG_WORD=_INTOSC_OSC_NOCLKOUT\\\&_WDT_OFF\\\&_LVP_OFF\\\&_DATA_CP_OFF\\\&_PWRTE_ON
# Defines the clock speed of the chip.  Used to calculate values for the
# baud rate registers.  It's in Hz, so 4000000 is 4MHz.
CFLAGS+=-DHZ=4000000
# Defines the baud rate for the chip.  19200L is the maximum sane, 
# compatible baud rate for the PIC16f628a's internal oscillator.
CFLAGS+=-DBAUD=19200L
# See Microchip's baud rate tables for whether you need HI=1 for your 
# baudrate or not.
CFLAGS+=-DBAUD_HI=1

## Where to find the source files common to all our controller boards
VPATH=../common/

## Which files are combined to make the object
OBJS=main.o packet.o eeprom-data.o databox.o

## Which base libraries are needed
LIBS+=$(SDCC_LIB)/pic$(PIC).lib $(SDCC_LIB)/libsdcc.lib
