/**
 * eeprom-data.c -- defines global EEPROM values
 * Copyright (C) 2007 Tyler Montbriand
 * monttyle@burningsmell.org
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the
 * Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

/**
 *	eeprom-data.c -- Defines many global constants for programming 
 *	into the PIC's eeprom memory, like the chip ID, the baud rate,
 *	lookup table for stepper patterns and binary-to-hex, etc.
 *
 *	You can selectively modify these at runtime by sending it a 
 *	PACKET_EEPROM packet.  If you change the baud rate, a reset will 
 *	be needed to put it into effect.
 */
#include "pic/pic14regs.h"
#include "reprap.h"
#include "packet.h"
#include "tsmuart.h"

// Converts a decimal number 0-15 into '0'-'9' and 'a'-'f' at compile time.
#define TOHEX_C(X)	(((X)<10)?((X)+'0'):((X)+('a'-10)))

#ifndef CHIPID
#error "CHIPID must be defined"
#endif

#ifndef CHIPCLASS
#error "CHIPCLASS must be defined"
//#define CHIPCLASS	CHIP_COMM
#endif

code Uint8 at PIC14_EEPROM eedata[]={
/*0x00*/	CHIPID,				// Chip ID
/*0x01*/	CHIPCLASS,			// Chip Class
/*0x02*/	SPBRG_VALUE(HZ,BAUD,BAUD_HI),	// Baud Rate register
/*0x03*/	BAUD_HI,			// BRGH value

/*0x04*/	'\n', '$', ' ', '\0',		/* Prompt */
		/* Stepper Table */
/*0x08*/	BIN8(0,0,0,0,1,0,0,1),	BIN8(0,0,0,0,0,0,0,1),
		BIN8(0,0,0,0,0,0,1,1),	BIN8(0,0,0,0,0,0,1,0),
		BIN8(0,0,0,0,0,1,1,0),	BIN8(0,0,0,0,0,1,0,0),
		BIN8(0,0,0,0,1,1,0,0),	BIN8(0,0,0,0,1,0,0,0),
/*0x10*/	/* binary-to-hex lookup table */
		'0', '1', '2', '3', '4', '5', '6', '7',
		'8', '9', 'a', 'b', 'c', 'd', 'e', 'f',
	/* Stored packets, see packet.c */
/*0x20*/	0x10, 0x11, 0x12, 0x13, 0x14, 0x15, 0x16, '\0',	// Repeat
/*0x28*/	0x11,  '#',  TOHEX_C(PACKET_ACK),
			'0',  '0',  '0',  '0',  '\0',		// ACK
/*0x30*/	0x11,  '#',  TOHEX_C(PACKET_NACK),
			'0',  '0',  '0',  '0',  '\0',		// NACK
/*0x38*/	'1',   '#',  TOHEX_C(PACKET_COMPLETE),
			'0',  '0',  '0',  '0',  '\0',		// Complete
/*0x40*/	'1',   '#',  TOHEX_C(PACKET_NET_EXT),
			'0',  '0',  '0',  '0',  '\0',		// Interrupt
/*0x48*/
};
