/**
 * tsmee.h -- macros for reading from and writing to the PIC's EEPROM
 * Copyright (C) 2007 Tyler Montbriand
 * monttyle@burningsmell.org
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
#ifndef __TSMEE_H__
#define __TSMEE_H__

#define PIC14_EEPROM    0x2100		// 14-bit PIC EEPROM offset
#define PIC16_EEPROM    0xf00000	// 16-bit PIC EEPROM offset

/**
 * Correct sequence for reading the EEPROM is:
 * @ Set address
 * @ Set RD bit
 * @ Read value from EEDATA
 *
 * This expression does exactly that, first setting EEADR and RD
 * before returning the value of EEDATA.
 */
#define EEPROM_READ(ADDR) (EEADR=ADDR,RD=1,EEDATA)

/** This EXACT SEQUENCE of instructions is needed, any deviation will
 *  cause the write to FAIL!  The PIC even counts the number of
 *  instructions to check if you did this right!  This means we need
 *  inline ASM, C isn't going to get it Just Right(tm).
 */
#define EEPROM_WRITE(ADDR,DATA)	do {			\
	EEADR=ADDR;	/* Set address		*/	\
	EEDATA=DATA;	/* Set data		*/	\
	WREN=1;		/* Enable EEPROM writes */	\
	EECON2=0x00;	/* Get in right bank	*/	\
	__asm	MOVLW	0x55		__endasm;	\
	__asm	MOVWF	EECON2		__endasm;	\
	__asm	MOVLW	0xaa		__endasm;	\
	__asm	MOVWF	EECON2		__endasm;	\
	__asm	BSF	EECON1,1	__endasm;	\
	while(WR);	/* Wait for write to finish */	\
	WREN=0;		/* Disable writes */		\
	} while(0)

#endif/*__TSMEE_H__*/
