/**
 * tsmtimer.h -- macros to control the pic16f628a timer0
 * Copyright (C) 2007 Tyler Montbriand
 * monttyle@burningsmell.org
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the
 * Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
#ifndef __TSMTIMER_H__
#define __TSMTIMER_H__

#include "tsmpic.h"

enum t0_clock_edge
{
	T0_RISING,
	T0_FALLING
};

enum t0_clock_src
{
	T0_INTERNAL,
	T0_EXTERNAL
};

#define TMR0_INIT(PRESCALE, SRC, EDGE)	do {				\
		T0CS=SRC;	/* Select clock source	*/		\
		PSA=SRC;	/* Assign prescaler	*/		\
		if(SRC == T0_INTERNAL) {				\
			PS0=PRESCALE&0x01;	/* Set up prescaler */	\
			PS1=(PRESCALE>>1)&0x01;				\
			PS2=(PRESCALE>>2)&0x01;				\
		} else {						\
			T0SE=EDGE;					\
		}							\
	} while(0)

#define TMR0_INT_INIT()		do {					\
		TMR0=0; /* Enable peripheral interrupts */		\
	} while(0)

#define TMR0_INT_START()	do { T0IE=1; } while(0)
#define TMR0_INT_STOP()		do { TOIE=0; } while(0)


#endif/*__TSMTIMER_H__*/
