/**
 * tsmuart.h -- macros to calculate baud rate given clock speed and baud rate, 
 * and macros to configure the USART.
 * Copyright (C) 2007 Tyler Montbriand
 * monttyle@burningsmell.org
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the
 * Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
#ifndef __TSMUART_H__
#define __TSMUART_H__

// These are fixed.  The 16f628a can only use these as transmit and recieve.
#define TX_PORT	2
#define RX_PORT	1
#define TX_BIT	(1<<TX_PORT)
#define RX_BIT	(1<<RX_PORT)

// The HI bit determines which division factor the PIC uses
#define BAUD_FACTOR(BAUD,HI)	(((HI)?16L:64L)*BAUD)

// Calculate value for SPBRG register given clock speed, baud rate, and HI bit
#define SPBRG_VALUE(HZ,BAUD,HI)	\
	(unsigned char)(((HZ)-BAUD_FACTOR(BAUD,HI))/BAUD_FACTOR(BAUD,HI))

// Initializes serial port registers(except interrupt-related ones).
#define SERIAL_INIT(HZ,BAUD,HI)	do {				\
	TRISB|=TX_BIT|RX_BIT;	/* These must be 1 for USART to work */	\
	SPBRG=SPBRG_VALUE(HZ,BAUD,HI);					\
	BRGH=HI;							\
	SYNC=0;			/* Disable sync/enable async	*/	\
	SPEN=1;			/* Enable serial port		*/	\
	TXEN=1;			/* Enable transmission		*/	\
	CREN=1;			/* Enable reception 		*/	\
	} while(0);


// Enables serial recieve interrupts
#define SERIAL_INT_INIT()	do	{				\
		PEIE=1;		/* Enable peripheral interrupts */	\
		RCIE=1;		/* Enable serial recieve interrupt */	\
		/*TXIE=1;*/	/* Enable serial tx interrupt */	\
		/*GIE=1;*/	/* Globally enable interrupts */	\
	} while(0);

#endif/*__TSMUART_H__*/
