/**
 * Controls a stepper motor with fractional speed and halfstepping.
 * Copyright (C) 2007 Tyler Montbriand
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the
 * Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
#include "pic/pic14regs.h"
#include "reprap.h"
#include "stepper.h"

Uint8		stepper_step;	// Phase of stepper motor, in half-steps
Sint16		stepper_pos;	// Current position of stepper motor

/**
 *	Returns 1 every (STEPPER_NUMER/STEPPER_DENOM) calls.
 */
static Sint8 check_fraction(void)
{
	STEPPER_FRAC-=STEPPER_NUMER;
	if(STEPPER_FRAC<0)
	{
		STEPPER_FRAC+=STEPPER_DENOM;
		return(1);
	}

	return(0);
}

/**
 *	Output stepper phase pattern on A0-A3
 */
void stepper_show(void)
{
	Uint8 tmp;
	tmp=PORTA&0xf0;
	tmp|=EEPROM_READ(EE_STEPPER_TABLE|(stepper_pos&0x07));
	PORTA=tmp;
}

/**
 *	Increments position and updates phase.  Moves every
 *	(STEPPER_NUMER/STEPPER_DENOM) calls.  Returns 0 on okay, and
 *	-1 on completion.
 */
Sint8 stepper_move(void)
{
	if(check_fraction())
	{
		if(stepper_pos < STEPPER_DEST)
		{
			stepper_pos++;
			stepper_step++;
		}
		else if(stepper_pos>STEPPER_DEST)
		{
			stepper_pos--;
			stepper_step--;
		}

		stepper_show();

		if(stepper_pos == STEPPER_DEST)
		{
			STEPPER_FRAC=0;
			return(-1);
		}
	}

	return(0);
}
